@@ -1,17 +1,17 @@
 <?php
-require_once("class_session.inc");
-require_once("class_layout.inc");
+require_once(__DIR__ . "/class_session.inc");
+require_once(__DIR__ . "/class_layout.inc");
 
 if (isset($symon['layout_dir'])) {
     $layout_dir = dir($symon['layout_dir']);
-    $layouts = array();
+    $layouts = [];
     while ($layout = $layout_dir->read()) {
-	$file_layout = $symon['layout_dir'].'/'.$layout;
-	$extension = get_extension($layout);
-	$layout = basename($layout, '.layout');
-	if (is_file($file_layout) && $extension == 'layout') {
-	    $symon['defaults']['layout']['namedvalues'][$layout] = $layout;
-	}
+        $file_layout = $symon['layout_dir'].'/'.$layout;
+        $extension = get_extension($layout);
+        $layout = basename($layout, '.layout');
+        if (is_file($file_layout) && $extension == 'layout') {
+            $symon['defaults']['layout']['namedvalues'][$layout] = $layout;
+        }
     }
     $symon['defaults']['layout']['namedvalues']['default'] = 'default';
 }
@@ -30,17 +30,15 @@ $hidden = '';
 
 <body bgcolor="#ffffff">
 <?php
-	$layout = $session->get("layout");
+$layout = $session->get("layout");
 
-	if ($layout == 'default') {
-		$layout = '';
-	}
+if ($layout == 'default') {
+    $layout = '';
+}
 
-	$l = new Layout($layout);
+$l = new Layout($layout);
+$l->render();
 ?>
 
-<?php
-	$l->render($session);
-?>
 </body>
 </html>
